==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-core/FrameworkInterface/SundanceEvalVectorArray.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */


#ifndef SUNDANCE_EVALVECTORARRAY_H
#define SUNDANCE_EVALVECTORARRAY_H


#include "SundanceDefs.hpp"
#include "SundanceEvalVector.hpp"
#include "Teuchos_RefCountPtr.hpp"
#include "Teuchos_Array.hpp"


namespace SundanceCore
{
using namespace SundanceUtils;
using namespace Teuchos;

class SparsitySuperset;

/**
 *
 */
class EvalVectorArray : public Array<RefCountPtr<EvalVector> >
{
public:
  /** */
  EvalVectorArray();

  /** */
  void copy(const RefCountPtr<EvalVectorArray>& other) ;

  /** */
  void steal(const RefCountPtr<EvalVectorArray>& other);

  /** */
  ostream& print(ostream& os, const SparsitySuperset* derivs) const ;
};
}


#endif /* EVALRESULTS */

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-core/FrameworkInterface/SundanceEvalVectorArray.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */


#ifndef SUNDANCE_EVALVECTORARRAY_H
#define SUNDANCE_EVALVECTORARRAY_H


#include "SundanceDefs.hpp"
#include "SundanceEvalVector.hpp"
#include "Teuchos_RefCountPtr.hpp"
#include "Teuchos_Array.hpp"


namespace Sundance
{
using namespace Sundance;
using namespace Teuchos;

class SparsitySuperset;

/**
 *
 */
class EvalVectorArray : public Array<RCP<EvalVector> >
{
public:
  /** */
  EvalVectorArray();

  /** */
  void copy(const RCP<EvalVectorArray>& other) ;

  /** */
  void steal(const RCP<EvalVectorArray>& other);

  /** */
  ostream& print(ostream& os, const SparsitySuperset* derivs) const ;
};
}


#endif /* EVALRESULTS */
